;; Generated package description from tmr.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "tmr" "1.4.0.0.20260823.2" "Set timers using a convenient notation" '((emacs "29.1")) :commit "b967e413e295045bbf12ec0e2c90932ec2bc8780" :authors '(("Protesilaos" . "info@protesilaos.com") ("Damien Cassou" . "damien@cassou.me") ("Daniel Mendler" . "mail@daniel-mendler.de") ("Steven Allen" . "steven@stebalien.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :keywords '("convenience" "timer") :url "https://github.com/protesilaos/tmr")
